package VMOMI::GuestOsDescriptorSupportLevel;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
